==> sddm_0.11.0.orig.tar.gz: sddm-0.11.0/data/translations/lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt">
<context>
    <name>TextConstants</name>
    <message>
        <source>Welcome to %1</source>
        <translation>Jus sveikina %1</translation>
    </message>
    <message>
        <source>Warning, Caps Lock is ON!</source>
        <translation>Dėmesio, įjungtos Didžiosios raidės!</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Atsijungti</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Prisijungti</translation>
    </message>
    <message>
        <source>Login failed</source>
        <translation>Prisijungimas nepavyko</translation>
    </message>
    <message>
        <source>Login succeeded</source>
        <translation>Prisijungimas pavyko</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Slaptažodis</translation>
    </message>
    <message>
        <source>Enter your username and password</source>
        <translation>Įveskite savo naudotojo vardą ir slaptažodį</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Paleisti iš naujo</translation>
    </message>
    <message>
        <source>Session</source>
        <translation>Sesija</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Išjungti</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>Naudotojo vardas</translation>
    </message>
    <message>
        <source>Select your user and enter password</source>
        <translation>Pasirinkite savo naudotoją ir įveskite slaptažodį</translation>
    </message>
</context>
</TS>

==> sddm-0.15.0.tar.gz: sddm-0.15.0/data/translations/lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>TextConstants</name>
    <message>
        <source>Welcome to %1</source>
        <translation>Jus sveikina %1</translation>
    </message>
    <message>
        <source>Warning, Caps Lock is ON!</source>
        <translation>Įspėjimas, įjungtos Didžiosios raidės!</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Išdėstymas</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Prisijungti</translation>
    </message>
    <message>
        <source>Login failed</source>
        <translation>Prisijungimas nepavyko</translation>
    </message>
    <message>
        <source>Login succeeded</source>
        <translation>Prisijungimas pavyko</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Slaptažodis</translation>
    </message>
    <message>
        <source>Enter your username and password</source>
        <translation>Įveskite savo naudotojo vardą ir slaptažodį</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Paleisti iš naujo</translation>
    </message>
    <message>
        <source>Session</source>
        <translation>Seansas</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Išjungti</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>Naudotojo vardas</translation>
    </message>
    <message>
        <source>Select your user and enter password</source>
        <translation>Pasirinkite savo naudotoją ir įveskite slaptažodį</translation>
    </message>
</context>
</TS>
